@@ -43,6 +43,7 @@ ERROR = "ERROR"
 DEVICE_OWNER_COMPUTE_PREFIX = "compute:"
 DEVICE_OWNER_NETWORK_PREFIX = "network:"
 DEVICE_OWNER_NEUTRON_PREFIX = "neutron:"
+DEVICE_OWNER_BAREMETAL_PREFIX = "baremetal:"
 
 DEVICE_OWNER_ROUTER_HA_INTF = (DEVICE_OWNER_NETWORK_PREFIX +
                                "router_ha_interface")
@@ -257,6 +258,10 @@ class Sentinel(object):
         # Always return the same object because this is essentially a constant.
         return self
 
+    def __copy__(self):
+        # called via copy.copy(x)
+        return self
+
 
 #############################
 # Attribute related constants
@@ -279,3 +284,13 @@ VHOST_USER_DEVICE_PREFIX = 'vhu'
 VETH_DEVICE_PREFIX = 'qvo'
 # prefix for SNAT interface in DVR
 SNAT_INT_DEV_PREFIX = 'sg-'
+
+
+##########################
+# Plugin related constants
+##########################
+# Plugin constants that are universally used across all neutron repos.
+# The alias for the core plugin.
+CORE = 'CORE'
+# The alias for the L3 plugin.
+L3 = 'L3_ROUTER_NAT'
